The ocean covers nearly 70% of the Earth's surface. Most of the excess energy that accumulates in the Earth system due to increasing concentrations of greenhouse gases is taken up by the ocean. The added energy warms the ocean and this warming causes the water to expand, which in turn leads to sea-level rise. The melting of ice on the land also adds to sea level rise. The surface layers of the ocean have warmed more rapidly than the deeper interior, mirrored in the rise of global mean sea-surface temperature and in the increased incidence of marine heatwaves.

As the concentration of CO2 in the atmosphere increases, so too does the concentration of CO2 in the ocean. This affects ocean chemistry, lowering the average pH of the water, a process known as ocean acidification, though it should be noted that the ocean remains, on average, slightly alkaline. All these changes have a broad range of impacts and interactions in the ocean and coastal areas.

## What the IPCC says

A1.6 It is virtually certain that the global upper ocean (0-700 m) has warmed since the 1970s and extremely likely that human influence is the main driver. It is virtually certain that human-caused CO2 emissions are the main driver of current global acidification of the surface open ocean. There is high confidence that oxygen levels have dropped in many upper ocean regions since the mid-20th century and medium confidence that human influence contributed to this drop.

A1.7 Global mean sea level increased by 0.20 [0.15 to 0.25] m between 1901 and 2018. The average rate of sea level rise was 1.3 [0.6 to 2.1] mm.yr-1 between 1901 and 1971, increasing to 1.9 [0.8 to 2.9] mm.yr-1 between 1971 and 2006, and further increasing to 3.7 [3.2 to 4.2] mm.yr-1 between 2006 and 2018 (high confidence). Human influence was very likely the main driver of these increases since at least 1971.

Chapter 2 Ocean pH has declined globally at the surface over the past four decades (virtually certain) and in all ocean basins in the ocean interior (high confidence) over the past 2-3 decades. A long-term increase in surface open ocean pH occurred over the past 50 million years (high confidence), and surface ocean pH as low as recent times is uncommon in the last 2 million years (medium confidence)

Chapter 9 Since the 1980s [marine heatwaves] have also become more intense and longer. Satellite observations and reanalyses of SST show an increase in intensity of 0.04°C per decade from 1982 to 2016, an increase in spatial extent of 19% per decade from 1982 to 2016, and an increase in annual MHW days of 54% between the 1987-2016 period compared to 1925-1954. The SROCC assessed that 84-90% of all MHWs that occurred between 2006 and 2015 are very likely caused by anthropogenic warming. There is new evidence since SROCC that the frequency of the most impactful marine heatwaves over the last few decades has increased more than 20-fold because of anthropogenic global warming. In summary, there is high confidence that MHWs have increased in frequency over the 20th century, with an approximate doubling from 1982 to 2016, and medium confidence that they have become more intense and longer since the 1980s